@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2021-09-07 10:50:00
+@LastEditTime: 2021-09-09 14:58:41
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -33,24 +33,21 @@ class TaskInfoListHandler(TaoBaseHandler):
         is_log = self.get_param("is_log",False)
         task_base_model = TaskBaseModel(context=self)
         app_key, app_secret = self.get_app_key_secret()
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, task_types)
+        invoke_result_data = self.business_process_executing(self.request_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        task_list = task_base_model.get_client_task_list(app_id, act_id, module_id, user_id, task_types, app_key, app_secret, is_log)
+        task_list = task_base_model.get_client_task_list(app_id, act_id, module_id, user_id, task_types, app_key, app_secret, is_log, invoke_result_data.data["daily_repeat_browse"])
         return self.response_json_success(self.business_process_executed(task_list))
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, task_types):
+    def business_process_executing(self, request_params):
         """
         :description: 执行前事件
-        :param app_id:应用标识
-        :param act_id:活动标识
-        :param module_id:活动模块标识
-        :param user_id:用户标识
-        :param task_types:任务类型 多个逗号,分隔
+        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
+        invoke_result_data.data = {"daily_repeat_browse": False}
         return invoke_result_data
 
     def business_process_executed(self, task_list):
@@ -95,7 +92,7 @@ class ReceiveRewardHandler(TaoBaseHandler):
         invoke_result_data = task_base_model.process_receive_reward(app_id, act_id, module_id, user_id, login_token, task_id, task_sub_type, self.__class__.__name__, self.request_code)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data)
+        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, task_id, task_sub_type)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -116,10 +113,17 @@ class ReceiveRewardHandler(TaoBaseHandler):
         invoke_result_data = InvokeResultData()
         return invoke_result_data
 
-    def business_process_executed(self, invoke_result_data):
+    def business_process_executed(self, invoke_result_data,app_id, act_id, user_id, module_id, login_token, task_id,task_sub_type):
         """
         :description: 执行后事件
         :param invoke_result_data:框架处理结果
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
+        :param task_id:任务标识
+        :param task_sub_type:子任务类型
         :return:
         :last_editors: HuangJianYi
         """
@@ -155,7 +159,7 @@ class FreeGiftHandler(TaoBaseHandler):
         invoke_result_data = task_base_model.process_free_gift(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_new_user"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data)
+        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -175,10 +179,15 @@ class FreeGiftHandler(TaoBaseHandler):
         invoke_result_data.data = {"check_new_user":True,"check_user_nick":True,"continue_request_expire":5}
         return invoke_result_data
 
-    def business_process_executed(self, invoke_result_data):
+    def business_process_executed(self, invoke_result_data,app_id, act_id, user_id, module_id, login_token):
         """
         :description: 执行后事件
         :param invoke_result_data:框架处理结果
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
         :return:
         :last_editors: HuangJianYi
         """
@@ -214,7 +223,7 @@ class OneSignHandler(TaoBaseHandler):
         invoke_result_data = task_base_model.process_one_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_new_user"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data)
+        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -234,10 +243,15 @@ class OneSignHandler(TaoBaseHandler):
         invoke_result_data.data = {"check_new_user": True, "check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
-    def business_process_executed(self, invoke_result_data):
+    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token):
         """
         :description: 执行后事件
         :param invoke_result_data:框架处理结果
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
         :return:
         :last_editors: HuangJianYi
         """
@@ -273,7 +287,7 @@ class WeeklySignHandler(TaoBaseHandler):
         invoke_result_data = task_base_model.process_weekly_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_new_user"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data)
+        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -293,10 +307,79 @@ class WeeklySignHandler(TaoBaseHandler):
         invoke_result_data.data = {"check_new_user": False, "check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
-    def business_process_executed(self, invoke_result_data):
+    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token):
         """
         :description: 执行后事件
         :param invoke_result_data:框架处理结果
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
+        :return:
+        :last_editors: HuangJianYi
+        """
+        return invoke_result_data
+
+
+class CumulativeSignHandler(TaoBaseHandler):
+    """
+    :description: 处理累计签到任务
+    """
+    @filter_check_params("act_id,tb_user_id,login_token")
+    def get_async(self):
+        """
+        :description: 处理累计签到任务
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param tb_user_id:用户标识
+        :param login_token:访问令牌
+        :return: 
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_taobao_param().source_app_id
+        act_id = int(self.get_param("act_id", 0))
+        user_id = int(self.get_param("tb_user_id", 0))
+        module_id = int(self.get_param("module_id", 0))
+        login_token = self.get_param("login_token")
+        task_base_model = TaskBaseModel(context=self)
+
+        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        invoke_result_data = task_base_model.process_cumulative_sign(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_new_user"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        return self.response_json_success(invoke_result_data.data)
+
+    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token):
+        """
+        :description: 执行前事件
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
+        :return:
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        invoke_result_data.data = {"check_new_user": False, "check_user_nick": True, "continue_request_expire": 5}
+        return invoke_result_data
+
+    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token):
+        """
+        :description: 执行后事件
+        :param invoke_result_data:框架处理结果
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
         :return:
         :last_editors: HuangJianYi
         """
@@ -328,18 +411,18 @@ class InviteNewUserHandler(TaoBaseHandler):
         invite_user_id = int(self.get_param("invite_user_id", 0))
         task_base_model = TaskBaseModel(context=self)
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
+        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token, invite_user_id)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data = task_base_model.process_invite_new_user(app_id, act_id, module_id, user_id, login_token, invite_user_id, self.__class__.__name__, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data)
+        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token, invite_user_id)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token):
+    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token, invite_user_id):
         """
         :description: 执行前事件
         :param app_id:应用标识
@@ -347,6 +430,7 @@ class InviteNewUserHandler(TaoBaseHandler):
         :param module_id:活动模块标识
         :param user_id:用户标识
         :param login_token:访问令牌
+        :param invite_user_id:邀请用户标识
         :return:
         :last_editors: HuangJianYi
         """
@@ -354,10 +438,16 @@ class InviteNewUserHandler(TaoBaseHandler):
         invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
-    def business_process_executed(self, invoke_result_data):
+    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, invite_user_id):
         """
         :description: 执行后事件
         :param invoke_result_data:框架处理结果
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
+        :param invite_user_id:邀请用户标识
         :return:
         :last_editors: HuangJianYi
         """
@@ -389,18 +479,18 @@ class InviteJoinMemberHandler(TaoBaseHandler):
         invite_user_id = int(self.get_param("invite_user_id", 0))
         task_base_model = TaskBaseModel(context=self)
 
-        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token)
+        invoke_result_data = self.business_process_executing(app_id, act_id, user_id, module_id, login_token,invite_user_id)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         invoke_result_data = task_base_model.process_invite_join_member(app_id, act_id, module_id, user_id, login_token, invite_user_id, self.__class__.__name__, self.request_code, invoke_result_data.data["check_new_user"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data)
+        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token,invite_user_id)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
 
-    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token):
+    def business_process_executing(self, app_id, act_id, user_id, module_id, login_token, invite_user_id):
         """
         :description: 执行前事件
         :param app_id:应用标识
@@ -408,6 +498,7 @@ class InviteJoinMemberHandler(TaoBaseHandler):
         :param module_id:活动模块标识
         :param user_id:用户标识
         :param login_token:访问令牌
+        :param invite_user_id:邀请用户标识
         :return:
         :last_editors: HuangJianYi
         """
@@ -415,10 +506,16 @@ class InviteJoinMemberHandler(TaoBaseHandler):
         invoke_result_data.data = {"check_new_user": True, "check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
-    def business_process_executed(self, invoke_result_data):
+    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token, invite_user_id):
         """
         :description: 执行后事件
         :param invoke_result_data:框架处理结果
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
+        :param invite_user_id:邀请用户标识
         :return:
         :last_editors: HuangJianYi
         """
@@ -454,7 +551,7 @@ class ShareReportHandler(TaoBaseHandler):
         invoke_result_data = task_base_model.process_share_report(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data)
+        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -474,10 +571,15 @@ class ShareReportHandler(TaoBaseHandler):
         invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
-    def business_process_executed(self, invoke_result_data):
+    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token):
         """
         :description: 执行后事件
         :param invoke_result_data:框架处理结果
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
         :return:
         :last_editors: HuangJianYi
         """
@@ -515,7 +617,7 @@ class CollectGoodsHandler(TaoBaseHandler):
         invoke_result_data = task_base_model.process_collect_goods(app_id, act_id, module_id, user_id, login_token, goods_id, self.__class__.__name__, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data)
+        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -535,10 +637,15 @@ class CollectGoodsHandler(TaoBaseHandler):
         invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
-    def business_process_executed(self, invoke_result_data):
+    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token):
         """
         :description: 执行后事件
         :param invoke_result_data:框架处理结果
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
         :return:
         :last_editors: HuangJianYi
         """
@@ -576,7 +683,7 @@ class BrowseGoodsHandler(TaoBaseHandler):
         invoke_result_data = task_base_model.process_browse_goods(app_id, act_id, module_id, user_id, login_token, goods_id, self.__class__.__name__, invoke_result_data.data["daily_repeat_browse"], invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data)
+        invoke_result_data = self.business_process_executed(invoke_result_data,app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -596,10 +703,15 @@ class BrowseGoodsHandler(TaoBaseHandler):
         invoke_result_data.data = {"daily_repeat_browse":False,"check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
-    def business_process_executed(self, invoke_result_data):
+    def business_process_executed(self, invoke_result_data,app_id, act_id, user_id, module_id, login_token):
         """
         :description: 执行后事件
         :param invoke_result_data:框架处理结果
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
         :return:
         :last_editors: HuangJianYi
         """
@@ -635,7 +747,7 @@ class FavorStoreHandler(TaoBaseHandler):
         invoke_result_data = task_base_model.process_favor_store(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data)
+        invoke_result_data = self.business_process_executed(invoke_result_data,app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -655,10 +767,15 @@ class FavorStoreHandler(TaoBaseHandler):
         invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
-    def business_process_executed(self, invoke_result_data):
+    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token):
         """
         :description: 执行后事件
         :param invoke_result_data:框架处理结果
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
         :return:
         :last_editors: HuangJianYi
         """
@@ -694,7 +811,7 @@ class JoinMemberHandler(TaoBaseHandler):
         invoke_result_data = task_base_model.process_join_member(app_id, act_id, module_id, user_id, login_token, self.__class__.__name__, self.request_code, invoke_result_data.data["check_user_nick"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data)
+        invoke_result_data = self.business_process_executed(invoke_result_data, app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -714,10 +831,15 @@ class JoinMemberHandler(TaoBaseHandler):
         invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
-    def business_process_executed(self, invoke_result_data):
+    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token):
         """
         :description: 执行后事件
         :param invoke_result_data:框架处理结果
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
         :return:
         :last_editors: HuangJianYi
         """
@@ -763,7 +885,7 @@ class BrowseSiteHandler(TaoBaseHandler):
         invoke_result_data = task_base_model.process_browse_site(app_id, act_id, module_id, user_id, login_token, task_type, task_sub_type, self.__class__.__name__, invoke_result_data.data["check_user_nick"], invoke_result_data.data["continue_request_expire"])
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        invoke_result_data = self.business_process_executed(invoke_result_data)
+        invoke_result_data = self.business_process_executed(invoke_result_data,app_id, act_id, user_id, module_id, login_token)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         return self.response_json_success(invoke_result_data.data)
@@ -783,10 +905,15 @@ class BrowseSiteHandler(TaoBaseHandler):
         invoke_result_data.data = {"check_user_nick": True, "continue_request_expire": 5}
         return invoke_result_data
 
-    def business_process_executed(self, invoke_result_data):
+    def business_process_executed(self, invoke_result_data, app_id, act_id, user_id, module_id, login_token):
         """
         :description: 执行后事件
         :param invoke_result_data:框架处理结果
+        :param app_id:应用标识
+        :param act_id:活动标识
+        :param module_id:活动模块标识
+        :param user_id:用户标识
+        :param login_token:访问令牌
         :return:
         :last_editors: HuangJianYi
         """
