@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-09-07 10:26:43
+@LastEditTime: 2021-09-09 13:33:27
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -24,8 +24,9 @@ class LoginHandler(TaoBaseHandler):
     def get_async(self):
         """
         :description: 登录处理
-        :param act_id:活动标识
-        :param avatar:头像
+        :param act_id：活动标识
+        :param module_id：活动模块标识
+        :param avatar：头像
         :return:
         :last_editors: HuangJianYi
         """
@@ -48,11 +49,24 @@ class LoginHandler(TaoBaseHandler):
         invoke_result_data = user_base_model.save_user_by_openid(app_id, act_id, open_id, user_nick, avatar)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-
         invoke_result_data = self.business_process_executed(invoke_result_data)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        return self.response_json_success(invoke_result_data.data)
 
+    def business_process_executed(self, invoke_result_data, app_id, act_id, module_id, open_id, user_nick, avatar):
+        """
+        :description: 执行后事件
+        :param invoke_result_data:框架处理结果
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param module_id：活动模块标识
+        :param open_id：open_id
+        :param user_nick：昵称
+        :param avatar：头像
+        :return:
+        :last_editors: HuangJianYi
+        """
         user_info_dict = invoke_result_data.data
         stat_base_model = StatBaseModel(context=self)
         key_list_dict = {}
@@ -60,15 +74,6 @@ class LoginHandler(TaoBaseHandler):
         key_list_dict["VisitManCountEveryDay"] = 1
         key_list_dict["VisitManCountEveryDayIncrease"] = 1
         stat_base_model.add_stat_list(app_id, act_id, module_id, user_info_dict["user_id"], open_id, key_list_dict)
-        return self.response_json_success(invoke_result_data.data)
-
-    def business_process_executed(self,invoke_result_data):
-        """
-        :description: 执行后事件
-        :param invoke_result_data:框架处理结果
-        :return:
-        :last_editors: HuangJianYi
-        """
         return invoke_result_data
 
 
