@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-09-03 15:43:31
+@LastEditTime: 2021-09-08 17:55:34
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -237,7 +237,7 @@ class FrameBaseHandler(BaseApiHandler):
     def get_signature_md5(self,request_param_dict,encrypt_key=""):
         """
         :description: 参数按照加密规则进行MD5加密
-        :description: 签名规则 SignatureMD5= ((参数1=参数1值&参数2=参数2值&SignatureStamp={SignatureStamp}))+密钥)进行Md5加密转小写，参数顺序按照字母表的顺序排列
+        :description: 签名规则 signature_md5= ((参数1=参数1值&参数2=参数2值&signature_stamp={signature_stamp}))+密钥)进行Md5加密转小写，参数顺序按照字母表的顺序排列
         :param request_param_dict: 请求参数字典
         :param encrypt_key: 接口密钥
         :return: 加密后的md5值，由于跟客户端传来的加密参数进行校验
@@ -318,6 +318,23 @@ class FrameBaseHandler(BaseApiHandler):
                 app_secret = middler_product_dict["app_secret"]
         return app_key, app_secret
 
+    def set_default_headers(self):
+        """
+        :description: 设置默认头部，用于跨域请求
+        :return
+        :last_editors: HuangJianYi
+        """
+        allow_origin_list = config.get_value("allow_origin_list")
+        if not allow_origin_list:
+            return
+        origin = self.request.headers.get("Origin")
+        if origin in allow_origin_list:
+            self.set_header("Access-Control-Allow-Origin", origin)
+
+        self.set_header("Access-Control-Allow-Headers", "Origin,X-Requested-With,Content-Type,Accept,User-Token,Manage-ProductID,Manage-PageID,PYCKET_ID")
+        self.set_header("Access-Control-Allow-Methods", "POST,GET,OPTIONS")
+        self.set_header("Access-Control-Allow-Credentials", "true")
+
 
 class TaoBaseHandler(FrameBaseHandler):
 
@@ -504,9 +521,9 @@ class TaoBaseHandler(FrameBaseHandler):
         operation_log_model.add_entity(operation_log)
 
 
-class WeChatBaseHandler(FrameBaseHandler):
+class ClientBaseHandler(FrameBaseHandler):
     """
-    :description: 微信handler基类
+    :description: 客户端handler基类
     """
     device_info_dict = {}  # 头部参数
 
@@ -518,21 +535,28 @@ class WeChatBaseHandler(FrameBaseHandler):
         if self.__class__.__name__ == "IndexHandler":
             return
 
+        dict_par = {}
+        dict_par["open_id"] = self.get_request_param("user_id")
+        dict_par["app_id"] = self.get_request_param("app_id","1")
+
         try:
             # 将设备信息字符串转为字典类型
             clientheaderinfo_string = self.request.headers._dict.get("Clientheaderinfo")
             if clientheaderinfo_string:
                 self.device_info_dict = self.device_info_dict(clientheaderinfo_string)
 
-            user_id = self.get_param("user_id")
+            user_id = self.get_request_param("user_id")
             if user_id:
                 # 频繁请求校验
-                is_continue_request, error_message = self.check_continue_request(self.__class__.__name__, self.device_info_dict["pid"], user_id)
+
+                is_continue_request, error_message = self.check_continue_request(self.__class__.__name__, dict_par["app_id"], user_id)
                 if is_continue_request:
                     return self.response_json_error("error", error_message)
+                #每分钟流量UV计数,用于登录接口限制登录
+                self.add_request_user(str(dict_par["app_id"]), user_id)
 
         except Exception as ex:
-            self.logging_link_error("【微信handler基类】"+ str(ex))
+            self.logging_link_error("【客户端handler基类】" + str(ex))
 
 
     def device_info_dict(self, device_str):
@@ -544,6 +568,7 @@ class WeChatBaseHandler(FrameBaseHandler):
         device_info_dict = {}
         info_model = parse_qs(device_str)
         device_info_dict["pid"] = int(info_model["pid"][0])  # 产品标识
+        device_info_dict["chid"] = 0 if "chid" not in info_model.keys() else int(info_model["chid"][0]) # 渠道标识
         device_info_dict["height"] = 0 if "height" not in info_model.keys() else int(info_model["height"][0]) # 高度
         device_info_dict["width"] = 0 if "width" not in info_model.keys() else int(info_model["width"][0]) # 宽度
         device_info_dict["version"] = "" if "version" not in info_model.keys() else info_model["version"][0]  # 客户端版本号
@@ -552,7 +577,6 @@ class WeChatBaseHandler(FrameBaseHandler):
         device_info_dict["model_p"] = "" if "model" not in info_model.keys() else info_model["model"][0]  # 机型
         device_info_dict["lang"] = "" if "lang" not in info_model.keys() else info_model["lang"][0]  #语言
         device_info_dict["ver_no"] = "" if "ver_no" not in info_model.keys() else info_model["ver_no"][0]  #接口版本号
-        device_info_dict["chid"] = 0 if "chid" not in info_model.keys() else int(info_model["chid"][0]) # 渠道标识
         device_info_dict["signature_stamp"] = 0 if "signature_stamp" not in info_model.keys() else int(info_model["signature_stamp"][0]) # 时间搓秒
         device_info_dict["signature_md5"] = "" if "signature_md5" not in info_model.keys() else info_model["signature_md5"][0]  # 签名md5
         return device_info_dict
