@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2021-09-07 09:26:37
+@LastEditTime: 2021-09-09 14:37:49
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -40,7 +40,7 @@ class PayOrderListHandler(TaoBaseHandler):
         pay_date_start = self.get_param("pay_date_start")
         pay_date_end = self.get_param("pay_date_end")
         page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 10))
+        page_size = int(self.get_param("page_size", 20))
 
         order_base_model = OrderBaseModel(context=self)
         return self.response_json_success(order_base_model.get_tao_pay_order_list(app_id, act_id, tb_user_id, user_open_id, nick_name, pay_date_start, pay_date_end, page_size, page_index))
@@ -83,13 +83,13 @@ class PrizeOrderListHandler(TaoBaseHandler):
         telephone = self.get_param("telephone")
         address = self.get_param("address")
         real_name = self.get_param("real_name")
-        order_status = int(self.get_param("order_status", -1))
+        order_status = int(self.get_param("order_status",-10))
         create_date_start = self.get_param("create_date_start")
         create_date_end = self.get_param("create_date_end")
         order_by = self.get_param("order_by","create_date desc")
         is_search_roster = self.get_param("is_search_roster", False)
         page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 10))
+        page_size = int(self.get_param("page_size", 20))
 
         order_base_model = OrderBaseModel(context=self)
         return self.response_json_success(order_base_model.get_prize_order_list(app_id, act_id, tb_user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=is_search_roster, is_cache=False))
@@ -141,9 +141,27 @@ class PrizeRosterListHandler(TaoBaseHandler):
         page_size = int(self.get_param("page_size", 500))
         if is_order:
             prize_status = 1
+        condition = ""
+        params = []
+        order_by ="create_date desc"
+        invoke_result_data = self.business_process_executing(self.request_params)
+        if invoke_result_data.success == True:
+            condition = invoke_result_data.data["condition"]
+            params = invoke_result_data.data["params"]
+            order_by = invoke_result_data.data["order_by"]
         order_base_model = OrderBaseModel(context=self)
-        return self.response_json_success(order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end))
+        return self.response_json_success(order_base_model.get_prize_roster_list(app_id, act_id, module_id, user_id, user_open_id, user_nick, order_no, goods_type, prize_type, logistics_status, prize_status, pay_status, page_size, page_index, create_date_start, create_date_end,order_by=order_by, condition=condition,params=params))
 
+    def business_process_executing(self,request_params):
+        """
+        :description: 执行前事件
+        :param request_params: 请求参数字典
+        :return:
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        invoke_result_data.data = {"condition": "", "params": [], "order_by": "create_date desc"}
+        return invoke_result_data
 
 class UpdatePrizeOrderSellerRemarkHandler(TaoBaseHandler):
     """
@@ -265,7 +283,7 @@ class PrizeOrderExportHandler(TaoBaseHandler):
         create_date_end = self.get_param("create_date_end")
         order_by = self.get_param("order_by", "create_date desc")
         page_index = int(self.get_param("page_index", 0))
-        page_size = int(self.get_param("page_size", 10))
+        page_size = int(self.get_param("page_size", 20))
 
         order_base_model = OrderBaseModel(context=self)
         prize_order_list_dict = order_base_model.get_prize_order_list(app_id, act_id, tb_user_id, user_open_id, nick_name, order_no, real_name, telephone, address, order_status, create_date_start, create_date_end, page_size, page_index, order_by, is_search_roster=True, is_cache=False).data
