@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-11-16 13:44:20
-@LastEditTime: 2021-09-06 19:26:33
+@LastEditTime: 2021-09-09 14:49:47
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -33,12 +33,13 @@ class StatReportListHandler(TaoBaseHandler):
         end_date = self.get_param("end_date")
 
         stat_base_model = StatBaseModel(context=self)
-        return self.response_json_success(self.business_process_executed(stat_base_model.get_stat_report_list(app_id, act_id, module_id, start_date, end_date)))
+        return self.response_json_success(self.business_process_executed(stat_base_model.get_stat_report_list(app_id, act_id, module_id, start_date, end_date), self.request_params))
 
-    def business_process_executed(self, stat_report_list):
+    def business_process_executed(self, stat_report_list, request_params):
         """
         :description: 执行后事件
         :param stat_report_list:报表数据列表(表格)
+        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
@@ -68,12 +69,13 @@ class TrendReportListHandler(TaoBaseHandler):
         end_date = self.get_param("end_date")
 
         stat_base_model = StatBaseModel(context=self)
-        return self.response_json_success(self.business_process_executed(stat_base_model.get_trend_report_list(app_id, act_id, module_id, start_date, end_date)))
+        return self.response_json_success(self.business_process_executed(stat_base_model.get_trend_report_list(app_id, act_id, module_id, start_date, end_date), self.request_params))
 
-    def business_process_executed(self, trend_report_list):
+    def business_process_executed(self, trend_report_list, request_params):
         """
         :description: 执行后事件
         :param trend_report_list:报表数据列表(趋势图)
+        :param request_params: 请求参数字典
         :return:
         :last_editors: HuangJianYi
         """
