@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:52:51
-@LastEditTime: 2021-09-07 10:05:32
+@LastEditTime: 2021-09-09 11:01:39
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -100,12 +100,12 @@ class UpdateUserStatusHandler(TaoBaseHandler):
 
 class UpdateUserStatusByBlackHandler(TaoBaseHandler):
     """
-    :description: 更新用户状态(黑名单管理模式)
+    :description: 用户拉入黑名单(黑名单管理模式)
     """
     @filter_check_params("act_id,tb_user_id")
     def get_async(self):
         """
-        :description: 更新用户状态
+        :description: 用户拉入黑名单
         :param app_id：应用标识
         :param act_id：活动标识
         :param tb_user_id：用户标识
@@ -132,19 +132,44 @@ class AuditUserBlackHandler(TaoBaseHandler):
         :description: 审核黑名单状态
         :param black_id：用户黑名单管理标识
         :param audit_status：审核状态(0黑名单1申请中2同意3拒绝)
+        :param audit_remark：审核备注
         :return: response_json_success
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
         black_id = int(self.get_param("black_id", 0))
         audit_status = int(self.get_param("audit_status", 0))
+        audit_remark = self.get_param("audit_remark")
         user_base_model = UserBaseModel(context=self)
-        invoke_result_data = user_base_model.audit_user_black(app_id, black_id, audit_status)
+        invoke_result_data = user_base_model.audit_user_black(app_id, black_id, audit_status, audit_remark)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
         self.response_json_success()
 
 
+class UpdateAuditRemarkHandler(TaoBaseHandler):
+    """
+    docstring 修改审核备注
+    """
+    @filter_check_params("black_id,audit_status")
+    def get_async(self):
+        """
+        :description: 修改审核备注
+        :param black_id：用户黑名单管理标识
+        :param audit_remark：审核备注
+        :return: response_json_success
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_app_id()
+        black_id = int(self.get_param("black_id", 0))
+        audit_remark = self.get_param("audit_remark")
+        user_base_model = UserBaseModel(context=self)
+        invoke_result_data = user_base_model.update_audit_remark(app_id, black_id, audit_remark)
+        if invoke_result_data.success == False:
+            return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        self.response_json_success()
+
+
 class UserBlackListHandler(TaoBaseHandler):
     """
     获取黑名单管理列表
@@ -298,3 +323,57 @@ class AssetLogListHandler(TaoBaseHandler):
 
         asset_base_model = AssetBaseModel(context=self)
         self.response_json_success(asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, tb_user_id, asset_object_id, start_date, end_date, user_nick, user_open_id, source_type, source_object_id))
+
+
+class UserInfoListHandler(TaoBaseHandler):
+    """
+    :description: 用户信息列表
+    """
+    @filter_check_params("act_id")
+    def get_async(self):
+        """
+        :description: 用户信息列表
+        :param act_id：活动标识
+        :param tb_user_id：用户标识
+        :param user_open_id：_open_id
+        :param nick_name：用户昵称
+        :param user_state：_用户状态0正常1黑名单
+        :param page_index：页索引
+        :param page_size：页大小
+        :param start_date：创建时间开始
+        :param end_date：创建时间结束
+        :return PageInfo
+        :last_editors: HuangJianYi
+        """
+        app_id = self.get_app_id()
+        act_id = int(self.get_param("act_id", 0))
+        user_id = int(self.get_param("tb_user_id", 0))
+        open_id = self.get_param("user_open_id")
+        user_nick = self.get_param("nick_name")
+        user_state = int(self.get_param("user_state", -1))
+        page_index = int(self.get_param("page_index", 0))
+        page_size = int(self.get_param("page_size", 20))
+        start_date = self.get_param("start_date")
+        end_date = self.get_param("end_date")
+        user_base_model = UserBaseModel(context=self)
+        page_info = user_base_model.get_user_list(app_id, act_id, page_size, page_index, user_state, user_id, start_date, end_date, user_nick, open_id)
+        return self.reponse_json_success(self.business_process_executed(page_info, app_id, act_id, page_size, page_index, user_state, user_id, start_date, end_date, user_nick, open_id))
+
+    def business_process_executed(self, page_info, app_id, act_id, page_size, page_index, user_state, user_id, start_date, end_date, user_nick, open_id):
+        """
+        :description: 执行后事件
+        :param page_info:用户信息分页实体模型
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param user_id：用户标识
+        :param open_id：_open_id
+        :param user_nick：用户昵称
+        :param user_state：_用户状态0正常1黑名单
+        :param page_index：页索引
+        :param page_size：页大小
+        :param start_date：创建时间开始
+        :param end_date：创建时间结束
+        :return:
+        :last_editors: HuangJianYi
+        """
+        return page_info
\ No newline at end of file
