@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-09-01 16:08:19
+@LastEditTime: 2021-09-06 15:44:54
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -72,7 +72,7 @@ class SevenHelper:
          :param queue_name：自定义队列名称
          :param value：加入队列的数据
          :param expire：过期时间，单位秒
-         :return: bool true-代表入队成功，false-代表达到长度限制，进行拦截
+         :return:
          :last_editors: HuangJianYi
          """
         redis_init = SevenHelper.redis_init()
