@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2021-08-25 09:35:06
+@LastEditTime: 2021-09-08 19:33:19
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -16,6 +16,7 @@ from urllib.parse import quote
 import hashlib
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_framework.base_model import *
+from seven_cloudapp_frame.models.seven_model import InvokeResultData
 
 
 class WeChatHelper:
@@ -33,7 +34,7 @@ class WeChatHelper:
         :return: 返回字典包含字段 session_key,openid
         :last_editors: HuangJianYi
         """
-        redis_key = "wechat_code:" + str(code)
+        redis_key = "wechat_login_code:" + str(code)
         redis_init = SevenHelper.redis_init()
         code2_session_dict = redis_init.get(redis_key)
         if code2_session_dict:
@@ -60,7 +61,7 @@ class WeChatHelper:
             redis_init.set(f"wechat_sessionkey:{open_id}", session_key, ex=60 * 60)
             return res_result
         except Exception as ex:
-            self.logger_error.error("【微信code2_session】" + str(ex) + ":" + str(resp.text))
+            self.logger_error.error("【code2_session】" + str(ex) + ":" + str(resp.text))
             return None
 
     @classmethod
@@ -85,7 +86,7 @@ class WeChatHelper:
             wx_data_crypt = WeChatDataCrypt(app_id, session_key)
             data = wx_data_crypt.decrypt(encrypted_Data, iv)  #data中是解密的信息
         except Exception as ex:
-            self.logger_error.error("【微信decrypt_data_by_code】" + str(ex))
+            self.logger_error.error("【decrypt_data_by_code】" + str(ex))
         return data
 
     @classmethod
@@ -104,7 +105,7 @@ class WeChatHelper:
             wx_data_crypt = WeChatDataCrypt(app_id, session_key)
             data = wx_data_crypt.decrypt(encrypted_Data, iv)  #data中是解密的信息
         except Exception as ex:
-            self.logger_error.error("【微信decrypt_data】" + str(ex))
+            self.logger_error.error("【decrypt_data】" + str(ex))
         return data
 
     @classmethod
@@ -129,6 +130,7 @@ class WeChatHelper:
             array_data[child.tag] = value
         return array_data
 
+
 class WeChatDataCrypt:
     """
     :description: 微信数据解密帮助类
@@ -155,6 +157,7 @@ class WeChatDataCrypt:
     def _unpad(self, s):
         return s[:-ord(s[len(s) - 1:])]
 
+
 class WeChatPayRequest(object):
     """
     :description: 微信支付请求类
@@ -185,6 +188,7 @@ class WeChatPayRequest(object):
         :return: 
         :last_editors: HuangJianYi
         """
+        invoke_result_data = InvokeResultData()
         redis_key = "wechat_prepay_id:" + str(params['out_trade_no'])
         redis_init = SevenHelper.redis_init()
         prepay_id = redis_init.get(redis_key)
@@ -196,13 +200,20 @@ class WeChatPayRequest(object):
             if xmlresp['xml']['result_code'] == 'SUCCESS':
                 prepay_id = str(xmlresp['xml']['prepay_id'])
                 redis_init.set(redis_key, prepay_id, ex=3600 * 1)
-                return prepay_id
+                invoke_result_data.data = prepay_id
+                return invoke_result_data
             else:
-                self.logger_error.error("【{params['out_trade_no']},微信统一下单获取prepay_id】" + xmlresp['xml']['err_code_des'])
-                return WeixinError(xmlresp['xml']['err_code_des'])
+                self.logger_error.error(f"【{params['out_trade_no']},统一下单获取prepay_id】" + xmlresp['xml']['err_code_des'])
+                invoke_result_data.success = False
+                invoke_result_data.error_code="error"
+                invoke_result_data.error_message = xmlresp['xml']['err_code_des']
+                return invoke_result_data
         else:
-            self.logger_error.error("【{params['out_trade_no']},微信统一下单获取prepay_id】" + xmlresp['xml']['return_msg'])
-            return WeixinError(xmlresp['xml']['return_msg'])
+            self.logger_error.error(f"【{params['out_trade_no']},统一下单获取prepay_id】" + xmlresp['xml']['return_msg'])
+            invoke_result_data.success = False
+            invoke_result_data.error_code="error"
+            invoke_result_data.error_message = xmlresp['xml']['return_msg']
+            return invoke_result_data
 
     def create_order(self, out_trade_no, body, total_fee, spbill_create_ip, notify_url, open_id="", time_expire="", trade_type="JSAPI"):
         """
@@ -218,8 +229,8 @@ class WeChatPayRequest(object):
         :return: 
         :last_editors: HuangJianYi
         """
+        invoke_result_data = InvokeResultData()
         spbill_create_ip = spbill_create_ip if SevenHelper.is_ip(spbill_create_ip) == True else "127.0.0.1"
-
         params = {
             'appid': self.app_id,  # appid
             'mch_id': self.mch_id,  # 商户号
@@ -233,7 +244,10 @@ class WeChatPayRequest(object):
         }
         if trade_type == "JSAPI":
             if open_id == "":
-                return WeixinError("缺少必填参数open_id")
+                invoke_result_data.success = False
+                invoke_result_data.error_code="error"
+                invoke_result_data.error_message = "缺少必填参数open_id"
+                return invoke_result_data
             else:
                 params['openid'] = open_id
         if time_expire != "":
@@ -241,15 +255,16 @@ class WeChatPayRequest(object):
 
         # 开发者调用支付统一下单API生成预交易单
         unifiedorder_url = 'https://api.mch.weixin.qq.com/pay/unifiedorder'
-        prepay_id = self.get_prepay_id(unifiedorder_url, params)
-        if type(prepay_id) == WeixinError:
-            return prepay_id
-
+        invoke_result_data = self.get_prepay_id(unifiedorder_url, params)
+        if invoke_result_data.success == False:
+            return invoke_result_data
+        prepay_id = invoke_result_data.data
         params['prepay_id'] = prepay_id
         params['package'] = f"prepay_id={prepay_id}"
         params['timestamp'] = str(int(time.time()))
         sign_again_params = {'appId': params['appid'], 'nonceStr': params['nonce_str'], 'package': params['package'], 'signType': 'MD5', 'timeStamp': params['timestamp']}
-        return self._get_sign(sign_again_params)  # 返回给app
+        invoke_result_data.data = self._get_sign(sign_again_params)
+        return invoke_result_data  # 返回给app
 
     def query_order(self, out_trade_no="", transaction_id=""):
         """
@@ -259,8 +274,12 @@ class WeChatPayRequest(object):
         :return: 
         :last_editors: HuangJianYi
         """
+        invoke_result_data = InvokeResultData()
         if transaction_id == "" and out_trade_no == "":
-            return WeixinError("缺少必填参数transaction_id或out_trade_no")
+            invoke_result_data.success = False
+            invoke_result_data.error_code="error"
+            invoke_result_data.error_message = "缺少必填参数transaction_id或out_trade_no"
+            return invoke_result_data
         xmlresp = {}
         xml = ""
         try:
@@ -280,9 +299,13 @@ class WeChatPayRequest(object):
             msg = respone.text.encode('ISO-8859-1').decode('utf-8')
             xmlresp = xmltodict.parse(msg)
         except Exception as ex:
-            self.logger_error.error("【微信查询订单】" + str(ex) + ":" + str(xml))
-            return WeixinError("微信查询订单出现异常")
-        return xmlresp
+            self.logger_error.error("【查询订单】" + str(ex) + ":" + str(xml))
+            invoke_result_data.success = False
+            invoke_result_data.error_code="error"
+            invoke_result_data.error_message = "查询订单出现异常"
+            return invoke_result_data
+        invoke_result_data.data = xmlresp
+        return invoke_result_data
 
     def close_order(self, out_trade_no=""):
         """
@@ -291,8 +314,12 @@ class WeChatPayRequest(object):
         :return: 
         :last_editors: HuangJianYi
         """
+        invoke_result_data = InvokeResultData()
         if out_trade_no == "":
-            return WeixinError("缺少必填参数out_trade_no")
+            invoke_result_data.success = False
+            invoke_result_data.error_code="error"
+            invoke_result_data.error_message = "缺少必填参数out_trade_no"
+            return invoke_result_data
         xmlresp = {}
         try:
             params = {
@@ -306,10 +333,14 @@ class WeChatPayRequest(object):
             respone = requests.post(queryorder_url, xml, headers={'Content-Type': 'application/xml'})
             msg = respone.text.encode('ISO-8859-1').decode('utf-8')
             xmlresp = xmltodict.parse(msg)
+            invoke_result_data.data = xmlresp
+            return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【微信关闭订单】" + str(ex))
-            return WeixinError("微信关闭订单出现异常")
-        return xmlresp
+            self.logger_error.error("【关闭订单】" + str(ex))
+            invoke_result_data.success = False
+            invoke_result_data.error_code="error"
+            invoke_result_data.error_message = "关闭订单出现异常"
+            return invoke_result_data
 
     def get_pay_status(self, out_trade_no, transaction_id=""):
         """
@@ -318,10 +349,12 @@ class WeChatPayRequest(object):
         :return: 
         :last_editors: HuangJianYi
         """
-        xmlresp = self.query_order(out_trade_no, transaction_id)
-        if type(xmlresp) == WeixinError:
+        invoke_result_data = InvokeResultData()
+        invoke_result_data = self.query_order(out_trade_no, transaction_id)
+        if invoke_result_data.success == False:
             return ""
         else:
+            xmlresp = invoke_result_data.data
             if xmlresp['xml']['return_code'] == 'SUCCESS':
                 if xmlresp['xml']['result_code'] == 'SUCCESS':
                     return str(xmlresp['xml']['trade_state'] if xmlresp['xml'].__contains__("trade_state") else "")  # SUCCESS--支付成功REFUND--转入退款NOTPAY--未支付CLOSED--已关闭REVOKED--已撤销(刷卡支付)USERPAYING--用户支付中PAYERROR--支付失败(其他原因，如银行返回失败)ACCEPT--已接收，等待扣款
@@ -331,7 +364,12 @@ class WeChatPayRequest(object):
                 return ""
 
     def _get_nonceStr(self, length=32):
-        """生成随机字符串"""
+        """
+        :description: 生成随机字符串
+        :param transaction_id：微信订单号
+        :return: 
+        :last_editors: HuangJianYi
+        """
         import random
         chars = "abcdefghijklmnopqrstuvwxyz0123456789"
         strs = []
@@ -341,8 +379,9 @@ class WeChatPayRequest(object):
 
     def _key_value_url(self, value, urlencode):
         """
-        将键值对转为 key1=value1&key2=value2
-        对参数按照key=value的格式，并按照参数名ASCII字典序排序
+        :description:   将键值对转为 key1=value1&key2=value2 对参数按照key=value的格式，并按照参数名ASCII字典序排序
+        :return: 
+        :last_editors: HuangJianYi
         """
         slist = sorted(value)
         buff = []
@@ -354,8 +393,9 @@ class WeChatPayRequest(object):
 
     def _get_sign(self, params):
         """
-        生成sign
-        拼接API密钥
+        :description:生成sign拼接API密钥
+        :return: 
+        :last_editors: HuangJianYi
         """
         stringA = self._key_value_url(params, False)
         stringSignTemp = stringA + '&key=' + self.api_key  # APIKEY, API密钥，需要在商户后台设置
@@ -365,7 +405,9 @@ class WeChatPayRequest(object):
 
     def _get_req_xml(self, params):
         """
-        拼接XML
+        :description:拼接XML
+        :return: 
+        :last_editors: HuangJianYi
         """
         params = self._get_sign(params)
         xml = "<xml>"
@@ -376,6 +418,7 @@ class WeChatPayRequest(object):
         xml += "</xml>"
         return xml.encode("utf-8")
 
+
 class WeChatPayReponse(object):
     """
     :description: 微信支付响应类
@@ -389,17 +432,24 @@ class WeChatPayReponse(object):
         self.api_key = pay_config['api_key']
 
     def _format_bizquery_paramap(self, paraMap, urlencode):
-        """格式化参数，签名过程需要使用"""
+        """
+        :description: 格式化参数，签名过程需要使用
+        :return:
+        :last_editors: HuangJianYi
+        """
         slist = sorted(paraMap)
         buff = []
         for k in slist:
             v = quote(paraMap[k]) if urlencode else paraMap[k]
             buff.append("{0}={1}".format(k, v))
-
         return "&".join(buff)
 
     def _get_sign(self, obj):
-        """生成签名"""
+        """
+        :description: 生成签名
+        :return:
+        :last_editors: HuangJianYi
+        """
         # 签名步骤一：按字典序排序参数,format_bizquery_paramap已做
         String = self._format_bizquery_paramap(obj, False)
         # 签名步骤二：在string后加入KEY
@@ -412,7 +462,11 @@ class WeChatPayReponse(object):
         return result_
 
     def check_sign(self):
-        """校验签名"""
+        """
+        :description: 校验签名
+        :return:
+        :last_editors: HuangJianYi
+        """
         tmpData = dict(self.data)  # make a copy to save sign
         del tmpData['sign']
         sign = self._get_sign(tmpData)  # 本地签名
@@ -421,19 +475,27 @@ class WeChatPayReponse(object):
         return False
 
     def get_data(self):
-        """获取微信的通知的数据"""
+        """
+        :description: 获取微信的通知的数据
+        :return:
+        :last_editors: HuangJianYi
+        """
         return self.data
 
     def get_return_data(self, msg, ok=True):
-        """返回xml格式数据"""
+        """
+        :description: 返回xml格式数据
+        :return:
+        :last_editors: HuangJianYi
+        """
         code = "SUCCESS" if ok else "FAIL"
         return WeChatHelper.array_to_xml(dict(return_code=code, return_msg=msg))
 
+
 class WeChatRefundReponse(object):
     """
     :description: 微信退款响应类
     """
-
     logger_error = Logger.get_logger_by_name("log_error")
 
     def __init__(self, reponse_xml):
@@ -442,11 +504,19 @@ class WeChatRefundReponse(object):
         self.api_key = pay_config['api_key']
 
     def get_data(self):
-        """获取微信的通知的数据"""
+        """
+        :description:获取微信的通知的数据
+        :return: 
+        :last_editors: HuangJianYi
+        """
         return self.data
 
     def decode_req_info(self, req_info):
-        """解密退款通知加密参数req_info"""
+        """
+        :description:解密退款通知加密参数req_info
+        :return: 
+        :last_editors: HuangJianYi
+        """
         detail_info = CryptoHelper.aes_decrypt(req_info, CryptoHelper.md5_encrypt(self.api_key))
         dict_req_info = xmltodict.parse(detail_info)
         return dict_req_info
@@ -454,10 +524,3 @@ class WeChatRefundReponse(object):
     def get_return_data(self, msg, ok=True):
         code = "SUCCESS" if ok else "FAIL"
         return WeChatHelper.array_to_xml(dict(return_code=code, return_msg=msg))
-
-class WeixinError(Exception):
-    """
-    :description: 微信异常类
-    """
-    def __init__(self, msg):
-        super(WeixinError, self).__init__(msg)
\ No newline at end of file
