@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2021-09-06 17:26:46
+@LastEditTime: 2021-09-09 11:58:01
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -377,7 +377,7 @@ class OrderBaseModel(FrameBaseModel):
             return invoke_result_data
         if int(user_info_dict["user_state"]) == 1:
             invoke_result_data.success = False
-            invoke_result_data.error_code = "error"
+            invoke_result_data.error_code = "user_exception"
             invoke_result_data.error_message = "账号异常,请联系客服处理"
             return invoke_result_data
         
@@ -606,7 +606,6 @@ class OrderBaseModel(FrameBaseModel):
                         except Exception as ex:
                             self.context.logging_link_info(str(order) + "【同步淘宝支付订单】" + str(ex))
                             continue
-                    
                     if len(tao_pay_order_list) > 0:
                         result = TaoPayOrderModel(context=self.context).add_list(tao_pay_order_list)
                         if result == True and buy_num > 0: 
@@ -631,19 +630,20 @@ class OrderBaseModel(FrameBaseModel):
                             invoke_result_data.data["buy_num"] = buy_num
                             invoke_result_data.data["pay_price"] = pay_price
                             invoke_result_data.data["pay_num"] = pay_num
-                    
                         else:
                             invoke_result_data.success = False
                             invoke_result_data.error_code = "error"
                             invoke_result_data.error_message = "没有匹配订单"
-                        user_base_model = UserBaseModel(context=self.context)
-                        black_status = user_base_model.check_pull_black(user_info_dict,act_info_dict["is_black"],act_info_dict["refund_count"],all_order_list)
-                        if black_status == True:
-                            invoke_result_data.data["user_state"] = 1
                     else:
                         invoke_result_data.success = False
                         invoke_result_data.error_code = "error"
-                        invoke_result_data.error_message = "没有匹配订单"  
+                        invoke_result_data.error_message = "没有匹配订单"
+                    if len(all_order_list) >0:
+                        user_base_model = UserBaseModel(context=self.context)
+                        black_status = user_base_model.check_pull_black(user_info_dict,act_info_dict["is_black"],act_info_dict["refund_count"],all_order_list)
+                        if black_status == True:
+                            invoke_result_data.data = {} if not invoke_result_data.data else invoke_result_data.data
+                            invoke_result_data.data["user_state"] = 1
                 else:
                     invoke_result_data.success = False
                     invoke_result_data.error_code = "error"
@@ -658,7 +658,7 @@ class OrderBaseModel(FrameBaseModel):
 
         return invoke_result_data
         
-    def get_prize_roster_list(self,app_id,act_id,module_id,user_id,open_id="",user_nick="",order_no="",goods_type=-1,prize_type=-1,logistics_status=-1,prize_status=-1,pay_status=-1,page_size=20,page_index=0,create_date_start="",create_date_end="",order_by="create_date desc",field="*",is_cache=True):
+    def get_prize_roster_list(self,app_id,act_id,module_id,user_id,open_id="",user_nick="",order_no="",goods_type=-1,prize_type=-1,logistics_status=-1,prize_status=-1,pay_status=-1,page_size=20,page_index=0,create_date_start="",create_date_end="",order_by="create_date desc",field="*",condition="",params=[],is_cache=True):
         """
         :description: 用户中奖记录列表
         :description: 如果有进行数据缓存，创建中奖记录时需清掉依赖建
@@ -680,12 +680,16 @@ class OrderBaseModel(FrameBaseModel):
         :param create_date_end：结束时间
         :param order_by：排序
         :param field：查询字段
+        :param condition：条件
+        :param params：参数化数组
         :param is_cache：是否缓存
         :return: PageInfo
         :last_editors: HuangJianYi
         """
-        condition = "app_id=%s and act_id=%s"
-        params = [app_id,act_id]
+        if condition:
+            condition+=" AND "     
+        condition += "app_id=%s and act_id=%s"
+        params.extend([app_id,act_id])
         page_info = PageInfo(page_index, page_size, 0, [])
         
         if not app_id or not act_id:
