@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-09-06 19:40:54
+@LastEditTime: 2021-09-09 10:58:50
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -399,6 +399,7 @@ class UserBaseModel(FrameBaseModel):
                 user_black = UserBlack()
                 user_black.app_id = user_info.app_id
                 user_black.act_id = user_info.act_id
+                user_black.user_id = user_info.user_id
                 user_black.open_id = user_info.open_id
                 user_black.user_nick = user_info.user_nick
                 user_black.black_type = 2
@@ -480,12 +481,13 @@ class UserBaseModel(FrameBaseModel):
         user_black_model.update_entity(user_black, "audit_status,reason")
         return invoke_result_data
     
-    def audit_user_black(self,app_id,black_id,audit_status):
+    def audit_user_black(self,app_id,black_id,audit_status,audit_remark=""):
         """
         :description: 审核黑名单
         :param app_id：应用标识
         :param black_id：用户黑名单管理id
         :param audit_status：审核状态(0黑名单1申请中2同意3拒绝)
+        :param audit_remark：审核备注
         :return:
         :last_editors: HuangJianYi
         """
@@ -517,23 +519,60 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_message = "用户信息不存在"
             return invoke_result_data
         audit_date = SevenHelper.get_now_datetime()
+        condition = "audit_status=%s,audit_date=%s"
+        params = [audit_status, audit_date]
+        if audit_remark:
+            condition+=",audit_remark=%s"
+            params.append(audit_remark)
+        params.append(black_id)
         if audit_status == 0:
-            user_black_model.update_table("audit_status=%s,audit_date=%s,black_type=2", "id=%s", [audit_status, audit_date, black_id])
+            condition+=",black_type=2"
+            user_black_model.update_table(condition, "id=%s", params)
             user_info.user_state = 1
             user_info.modify_date = audit_date
             user_info_model.update_entity(user_info,"user_state,modify_date")
         elif audit_status == 2:
-            user_black_model.update_table("audit_status=%s,audit_date=%s", "id=%s", [audit_status, audit_date, black_id])
+            user_black_model.update_table(condition, "id=%s", params)
             user_info.user_state = 0
             user_info.modify_date = audit_date
             user_info.relieve_date = audit_date
             user_info_model.update_entity(user_info, "user_state,modify_date,modify_date")
         elif audit_status == 3:
-            user_black_model.update_table("audit_status=%s,audit_date=%s", "id=%s", [audit_status, audit_date, black_id])
+            user_black_model.update_table(condition, "id=%s", params)
 
         self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
         
         return invoke_result_data
+
+    def update_audit_remark(self,app_id,black_id,audit_remark):
+        """
+        :description: 修改审核备注
+        :param app_id：应用标识
+        :param black_id：用户黑名单管理id
+        :param audit_remark：审核备注
+        :return:
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        if black_id <= 0:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "param_error"
+            invoke_result_data.error_message = "参数不能为空或等于0"
+            return invoke_result_data
+        user_black_model = UserBlackModel(context=self.context)
+        black_info = user_black_model.get_entity_by_id(black_id)
+        if not black_info:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "找不到该条记录"
+            return invoke_result_data
+        if black_info.app_id != app_id:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message = "非法操作"
+            return invoke_result_data
+        user_black_model.update_table("audit_remark=%s", "id=%s", [audit_remark,black_id])
+        return invoke_result_data        
         
     def get_black_info_dict(self, app_id, act_id, user_id,is_cache=True):
         """
@@ -629,7 +668,7 @@ class UserBaseModel(FrameBaseModel):
                 refund_order_data = [i for i in all_order_data if i["refund_status"] not in self.refund_status()]
                 #如果不是黑用户 并且存在退款时间 代表黑用户解禁
                 if user_info_dict["relieve_date"] != '1900-01-01 00:00:00':
-                    refund_order_data = [i for i in refund_order_data if TimeHelper.format_time_to_datetime(i['pay_time']) > TimeHelper.format_time_to_datetime(user_info_dict["relieve_date"])]
+                    refund_order_data = [i for i in refund_order_data if TimeHelper.format_time_to_datetime(str(i['pay_time'])) > TimeHelper.format_time_to_datetime(str(user_info_dict["relieve_date"]))]
                 #超过变成黑用户
                 if len(refund_order_data) >= refund_count:
                     result = True
@@ -653,6 +692,7 @@ class UserBaseModel(FrameBaseModel):
                         user_black = UserBlack()
                         user_black.app_id = user_info_dict["app_id"]
                         user_black.act_id = user_info_dict["act_id"]
+                        user_black.user_id = user_info_dict["user_id"]
                         user_black.open_id = user_info_dict["open_id"]
                         user_black.user_nick = user_info_dict["user_nick"]
                         user_black.black_type = 1
