@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2021-09-06 18:07:11
+@LastEditTime: 2021-09-09 11:25:27
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -48,6 +48,7 @@ def seven_cloudapp_frame_route():
         (r"/client/free_gift", task.FreeGiftHandler),  #免费领取、新人有礼等任务
         (r"/client/one_sign", task.OneSignHandler),  #单次签到任务
         (r"/client/weekly_sign", task.WeeklySignHandler),  #每周签到任务
+        (r"/client/cumulative_sign", task.CumulativeSignHandler),  #累计签到任务
         (r"/client/invite_new_user", task.InviteNewUserHandler),  #邀请新用户任务
         (r"/client/invite_join_member", task.InviteJoinMemberHandler),  #邀请加入会员任务
         (r"/client/browse_site", task.BrowseSiteHandler),  #处理浏览网址相关任务 如：浏览店铺、浏览直播间、浏览会场/专题
@@ -100,9 +101,11 @@ def seven_cloudapp_frame_route():
         (r"/server/import_prize_order", order_s.ImportPrizeOrderHandler),  #导入发货订单
         (r"/server/stat_report_list", report_s.StatReportListHandler),  #报表数据列表(表格)
         (r"/server/trend_report_list", report_s.TrendReportListHandler),  #报表数据列表(趋势图)
+        (r"/server/user_info_list", user_s.UserInfoListHandler),  #用户信息列表
         (r"/server/update_user_status", user_s.UpdateUserStatusHandler),  #更新用户状态（0正常1黑名单）
         (r"/server/update_user_status_by_black", user_s.UpdateUserStatusByBlackHandler),  #更新用户状态(黑名单管理模式)
         (r"/server/audit_user_black", user_s.AuditUserBlackHandler),  #审核黑名单状态
+        (r"/server/update_audit_remark", user_s.UpdateAuditRemarkHandler),  #修改审核备注
         (r"/server/user_black_list", user_s.UserBlackListHandler),  #黑名单列表
         (r"/server/update_user_asset", user_s.UpdateUserAssetHandler),  #更新用户资产值
         (r"/server/batch_update_user_asset", user_s.BatchUpdateUserAssetHandler),  #批量更新用户资产值
